import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { WebService } from './../../providers/web.service';
import { ValidationService } from './../../providers/validation.service';
import { FormControl, FormGroup, FormBuilder, Validators, ValidationErrors } from '@angular/forms';

@Component({
  selector: 'app-addprovider',
  templateUrl: './addprovider.component.html',
  styleUrls: ['./addprovider.component.scss']
})
export class AddproviderComponent implements OnInit {
  providerForm: FormGroup;
  mobnumPattern = '^((\\+?)|0)?[0-9]{8,15}$';
  emailPattern = '^[a-z0-9._%+-]+@[a-z0-9.-]+\.[a-z]{2,4}$';
  providerSubmit: boolean;
  lang =  'en';
  error_msg: any[];
  funcName: any;
  loader: boolean;
  responseError: any;
  error: boolean;
  success: boolean;

  constructor(
    private router: Router,
    private route: ActivatedRoute,
    public vs: ValidationService,
    public service: WebService,
    private formBuilder: FormBuilder
    ) {
      this.loader = false;
      this.error = false;
      this.success = false;
      this.providerSubmit = false;
      this.error_msg = this.vs.errorList[this.lang];
    }

  ngOnInit() {
    this.providerForm = this.formBuilder.group({
      'name':  ['', Validators.compose([Validators.required])],
      'cr_manager':  ['', Validators.compose([Validators.required])],
      'cr_id':  ['', Validators.compose([Validators.required])],
      'contact':  ['', Validators.compose([Validators.required])],
      'location':  ['', Validators.compose([Validators.required])],
      'email_id': ['', Validators.compose([Validators.required, Validators.maxLength(50), Validators.pattern(this.emailPattern)])],
      // tslint:disable-next-line:max-line-length
      'phone':  ['', Validators.compose([Validators.required, Validators.minLength(8), Validators.maxLength(15), Validators.pattern(this.mobnumPattern)])],
      'type':  [3],
      'password': [''],
    });
  }

  goToPage(path, data = null) {
    console.log(data);
    this.router.navigateByUrl(path, {queryParams: data});
    document.body.scrollTop = document.documentElement.scrollTop = 0;
  }

  regProcess() {
    const This = this;
    this.error = false;
    this.success = false;
    let pass =  Math.round(Math.random() * 1000000);
    pass = this.pad(pass, 6, 0);
    this.providerForm.controls['password'].setValue(pass);
    console.log(this.providerForm.value);
    this.providerSubmit = true;
    if (this.providerForm.valid) {
      this.loader = true;
      const providerObj = this.providerForm.value;
      this.funcName = 'provider_create';
      this.service.post_data(this.funcName, providerObj).subscribe(response => {
        this.loader = false;
        console.log(response);
        if (response.code === 1) {
          this.success = true;
          this.providerSubmit = false;
          this.providerForm.reset();
        } else {
          this.error = true;
          this.responseError = this.vs.errorCode[this.lang][response.errorCode];
        }
      }, (error) => {
        this.error = false;
        this.responseError = this.vs.errorCode[this.lang]['ER08'];
      });
    }
    console.log('tested');
  }

  pad(n: any, width: any, z: any) {
    z = z || '0';
    n = n + '';
    return n.length >= width ? n : new Array(width - n.length + 1).join(z) + n;
  }

  cancelClick() {
    this.router.navigate(['/checker/delivery']);
  }

  logout() {
    this.service.logout();
  }

}
